pub struct NonSendData { /* private fields */ }Expand description
The type-erased backing storage and metadata for a single resource within a World.
If SEND is false, values of this type will panic if dropped from a different thread.
The type-erased backing storage and metadata for non send data within a World.
Values of this type will panic if dropped from a different thread.
Implementations
Sourceimpl NonSendData
impl NonSendData
Sourcepub fn is_present(&self) -> bool
pub fn is_present(&self) -> bool
Returns true if the resource is populated.
Sourcepub fn get_data(&self) -> Option<Ptr<'_>>
pub fn get_data(&self) -> Option<Ptr<'_>>
Returns a reference to the resource, if it exists.
Panics
This will panic if a value is present and is not accessed from the original thread it was inserted from.
Sourcepub fn get_ticks(&self) -> Option<ComponentTicks>
pub fn get_ticks(&self) -> Option<ComponentTicks>
Returns a reference to the resource’s change ticks, if it exists.